@@ -1,5 +1,11 @@
 var NAVTREEINDEX101 =
 {
+"namespacezypp_1_1solver_1_1detail.html#a929e271c57303057f74772ab5bab3884":[3,0,10,39,0,31],
+"namespacezypp_1_1solver_1_1detail.html#a9c29e8ab3519ca4e0ed2ed09f96e5266":[3,0,10,39,0,15],
+"namespacezypp_1_1solver_1_1detail.html#aa355ef2f7aebcd6488938458ed746a29":[3,0,10,39,0,41],
+"namespacezypp_1_1solver_1_1detail.html#aa54f39a4d8948be4483203fc605402b3":[3,0,10,39,0,25],
+"namespacezypp_1_1solver_1_1detail.html#aa9846fc857d06ea04ecf169c1a6d0be7":[3,0,10,39,0,43],
+"namespacezypp_1_1solver_1_1detail.html#aaca3a5360afd7ce7a7e226370ecc64bd":[3,0,10,39,0,37],
 "namespacezypp_1_1solver_1_1detail.html#ab56fd2d4cf2fda36702073f27160aad4":[3,0,10,39,0,13],
 "namespacezypp_1_1solver_1_1detail.html#ab74acaab634c06067ff5f785a976f1da":[3,0,10,39,0,47],
 "namespacezypp_1_1solver_1_1detail.html#ac1ea48913346af880b86234b4b5b6afb":[3,0,10,39,0,23],
@@ -243,11 +249,5 @@ var NAVTREEINDEX101 =
 "namespacezypp_1_1ui.html#add6cc53e8d263bf3cf369fcecd6175c7":[3,0,10,45,23],
 "namespacezypp_1_1ui.html#ae04d33cc40f69459a21d3dec2ce35b44":[3,0,10,45,22],
 "namespacezypp_1_1ui_1_1selfilter.html":[3,0,10,45,0],
-"namespacezypp_1_1url.html":[3,0,10,46],
-"namespacezypp_1_1url.html#a3efd25a6a62b74b6f5b27b95b68dc074":[3,0,10,46,13],
-"namespacezypp_1_1url.html#a49b96afbf1694ee0ece38383ecd95994":[3,0,10,46,17],
-"namespacezypp_1_1url.html#a6787f9f20751da18ff9fa8f9d5842911":[3,0,10,46,10],
-"namespacezypp_1_1url.html#a698c697a3a27ed7bd9f7d30d8942e1da":[3,0,10,46,20],
-"namespacezypp_1_1url.html#a7933ce1eb6148235abcbb5eaa67b43d6":[3,0,10,46,14],
-"namespacezypp_1_1url.html#a7ccc2a66d0cc57fd32b705d96f9eaaf6":[3,0,10,46,19]
+"namespacezypp_1_1url.html":[3,0,10,46]
 };
