@@ -1,5 +1,18 @@
 var NAVTREEINDEX112 =
 {
+"structzypp_1_1PluginFrame_1_1Impl.html#ae788cbcd7722024b9d3a9254ef2f036a":[4,0,7,170,0,13],
+"structzypp_1_1PluginFrame_1_1Impl.html#af7c009f6a520740e0731e1315523716a":[3,0,10,179,0,33],
+"structzypp_1_1PluginFrame_1_1Impl.html#af7c009f6a520740e0731e1315523716a":[4,0,7,170,0,33],
+"structzypp_1_1PluginFrame_1_1Impl.html#af8fdc0a73fc3ed581c4d6b63f50dc3f0":[3,0,10,179,55],
+"structzypp_1_1PluginFrame_1_1Impl.html#af8fdc0a73fc3ed581c4d6b63f50dc3f0":[3,0,10,179,0,31],
+"structzypp_1_1PluginFrame_1_1Impl.html#af8fdc0a73fc3ed581c4d6b63f50dc3f0":[4,0,7,170,55],
+"structzypp_1_1PluginFrame_1_1Impl.html#af8fdc0a73fc3ed581c4d6b63f50dc3f0":[4,0,7,170,0,31],
+"structzypp_1_1PluginFrame_1_1Impl.html#afc555c25a4c633623dcff37a5a90d21f":[3,0,10,179,0,6],
+"structzypp_1_1PluginFrame_1_1Impl.html#afc555c25a4c633623dcff37a5a90d21f":[4,0,7,170,0,6],
+"structzypp_1_1PluginFrame_1_1Impl.html#afcb1360545aae78ebd7ac27844388c0d":[3,0,10,179,0,11],
+"structzypp_1_1PluginFrame_1_1Impl.html#afcb1360545aae78ebd7ac27844388c0d":[4,0,7,170,0,11],
+"structzypp_1_1PluginFrame_1_1Impl.html#afdfeb6f13f3ed70466b73ba68d87a162":[3,0,10,179,0,12],
+"structzypp_1_1PluginFrame_1_1Impl.html#afdfeb6f13f3ed70466b73ba68d87a162":[4,0,7,170,0,12],
 "structzypp_1_1PluginScript_1_1Impl.html":[3,0,10,181,0],
 "structzypp_1_1PluginScript_1_1Impl.html":[4,0,7,172,0],
 "structzypp_1_1PluginScript_1_1Impl.html#a0c637018b93bc361da3355a3834ae637":[3,0,10,181,0,15],
@@ -236,18 +249,5 @@ var NAVTREEINDEX112 =
 "structzypp_1_1PurgeKernels_1_1Impl.html":[4,0,7,190,0],
 "structzypp_1_1PurgeKernels_1_1Impl.html#a1b9a22b926c4b2e49204bb9587d6820f":[3,0,10,199,0,9],
 "structzypp_1_1PurgeKernels_1_1Impl.html#a1b9a22b926c4b2e49204bb9587d6820f":[4,0,7,190,0,9],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a209cdee77c7d15116c619818cd839c86":[3,0,10,199,0,14],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a209cdee77c7d15116c619818cd839c86":[4,0,7,190,0,14],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a5ab5f8b5b5bca9cfe53ecbab8c35a3b9":[3,0,10,199,0,13],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a5ab5f8b5b5bca9cfe53ecbab8c35a3b9":[4,0,7,190,0,13],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a653ee93fad5b88ea8f70e8dbd2cc2f05":[3,0,10,199,0,3],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a653ee93fad5b88ea8f70e8dbd2cc2f05":[4,0,7,190,0,3],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a67426fe5c067701563ba2df32f702ecc":[3,0,10,199,0,8],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a67426fe5c067701563ba2df32f702ecc":[4,0,7,190,0,8],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a81d073ad7a555cafe4b96166fbe8b138":[3,0,10,199,0,12],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a81d073ad7a555cafe4b96166fbe8b138":[4,0,7,190,0,12],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a828862f7d5031501257d6caea82601ba":[3,0,10,199,0,2],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a828862f7d5031501257d6caea82601ba":[4,0,7,190,0,2],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a86574728b2a4a29f24b6282c4dfa45ca":[3,0,10,199,0,10],
-"structzypp_1_1PurgeKernels_1_1Impl.html#a86574728b2a4a29f24b6282c4dfa45ca":[4,0,7,190,0,10]
+"structzypp_1_1PurgeKernels_1_1Impl.html#a209cdee77c7d15116c619818cd839c86":[3,0,10,199,0,14]
 };
