@@ -1,8 +1,10 @@
 var NAVTREEINDEX27 =
 {
+"classzypp_1_1PoolQuery.html#a2decc6fc5ace985a53676a037bd1a7f5":[3,0,10,186,76],
+"classzypp_1_1PoolQuery.html#a2decc6fc5ace985a53676a037bd1a7f5":[4,0,7,177,76],
 "classzypp_1_1PoolQuery.html#a2e4c09d987fd3f4b7e2704c822acac41":[3,0,10,186,38],
 "classzypp_1_1PoolQuery.html#a2e4c09d987fd3f4b7e2704c822acac41":[4,0,7,177,38],
-"classzypp_1_1PoolQuery.html#a33cc75846962647af4cfb65714bd45e4":[3,0,10,724],
+"classzypp_1_1PoolQuery.html#a33cc75846962647af4cfb65714bd45e4":[3,0,10,725],
 "classzypp_1_1PoolQuery.html#a33cc75846962647af4cfb65714bd45e4":[3,0,10,186,75],
 "classzypp_1_1PoolQuery.html#a33cc75846962647af4cfb65714bd45e4":[4,0,7,177,75],
 "classzypp_1_1PoolQuery.html#a37e9acabb491f73e314db999faa4543f":[3,0,10,186,60],
@@ -117,7 +119,7 @@ var NAVTREEINDEX27 =
 "classzypp_1_1PoolQuery.html#ae30d4b6879e1f37becc8b029c2b68fa6":[4,0,7,177,42],
 "classzypp_1_1PoolQuery.html#ae52ce57ead70f9a50e19ea6fbe6761cd":[3,0,10,186,39],
 "classzypp_1_1PoolQuery.html#ae52ce57ead70f9a50e19ea6fbe6761cd":[4,0,7,177,39],
-"classzypp_1_1PoolQuery.html#ae75fbed6259694194c2db11a3474c8c6":[3,0,10,723],
+"classzypp_1_1PoolQuery.html#ae75fbed6259694194c2db11a3474c8c6":[3,0,10,724],
 "classzypp_1_1PoolQuery.html#ae75fbed6259694194c2db11a3474c8c6":[3,0,10,186,74],
 "classzypp_1_1PoolQuery.html#ae75fbed6259694194c2db11a3474c8c6":[4,0,7,177,74],
 "classzypp_1_1PoolQuery.html#ae85d1fa3c881c0cbeddfd557587c7df4":[3,0,10,186,1],
@@ -150,7 +152,7 @@ var NAVTREEINDEX27 =
 "classzypp_1_1PoolQueryResult.html#a7109d5c4215929721d2f62a0d7c54da0":[4,0,7,179,22],
 "classzypp_1_1PoolQueryResult.html#a717f4d41c807c1de8f83379cc76b2ff4":[3,0,10,188,12],
 "classzypp_1_1PoolQueryResult.html#a717f4d41c807c1de8f83379cc76b2ff4":[4,0,7,179,12],
-"classzypp_1_1PoolQueryResult.html#a731461694fe4d0ea9eb82d5ba0359f71":[3,0,10,725],
+"classzypp_1_1PoolQueryResult.html#a731461694fe4d0ea9eb82d5ba0359f71":[3,0,10,726],
 "classzypp_1_1PoolQueryResult.html#a731461694fe4d0ea9eb82d5ba0359f71":[3,0,10,188,29],
 "classzypp_1_1PoolQueryResult.html#a731461694fe4d0ea9eb82d5ba0359f71":[4,0,7,179,29],
 "classzypp_1_1PoolQueryResult.html#a7f14b9a432050d698f5509e07bd1ef7b":[3,0,10,188,11],
@@ -247,7 +249,5 @@ var NAVTREEINDEX27 =
 "classzypp_1_1PoolQuery_1_1Impl.html#ad4cada081ae1d8483b4a4345aa6649c1":[4,0,7,177,0,3],
 "classzypp_1_1PoolQuery_1_1Impl.html#adff2876e03187c9489802567e420dd1e":[3,0,10,186,0,5],
 "classzypp_1_1PoolQuery_1_1Impl.html#adff2876e03187c9489802567e420dd1e":[4,0,7,177,0,5],
-"classzypp_1_1PoolQuery_1_1Impl.html#ae70b263faf4d8f18100fd9c9ec8924cc":[3,0,10,186,0,8],
-"classzypp_1_1PoolQuery_1_1Impl.html#ae70b263faf4d8f18100fd9c9ec8924cc":[4,0,7,177,0,8],
-"classzypp_1_1PoolQuery_1_1Impl.html#ae88698b401f7623685ebefa520fa73fd":[3,0,10,186,0,12]
+"classzypp_1_1PoolQuery_1_1Impl.html#ae70b263faf4d8f18100fd9c9ec8924cc":[3,0,10,186,0,8]
 };
