@@ -1,5 +1,7 @@
 var NAVTREEINDEX41 =
 {
+"classzypp_1_1base_1_1LogControl.html#a7af8ff95ddc1f7e1737b066ec8eca3ad":[3,0,10,2,4,14],
+"classzypp_1_1base_1_1LogControl.html#a7af8ff95ddc1f7e1737b066ec8eca3ad":[4,0,7,1,3,14],
 "classzypp_1_1base_1_1LogControl.html#a8319233a0c13effdc0451e57cc375a90":[3,0,10,2,4,3],
 "classzypp_1_1base_1_1LogControl.html#a8319233a0c13effdc0451e57cc375a90":[4,0,7,1,3,3],
 "classzypp_1_1base_1_1LogControl.html#a8b129042adedbfbf5afb54c6214e42c4":[3,0,10,2,4,10],
@@ -247,7 +249,5 @@ var NAVTREEINDEX41 =
 "classzypp_1_1bit_1_1BitField.html#acb4eae56a8ce0610290b428bb87e7206":[4,0,7,2,1,36],
 "classzypp_1_1bit_1_1BitField.html#ad29610309310b073e12a4211b14049da":[3,0,10,3,16],
 "classzypp_1_1bit_1_1BitField.html#ad29610309310b073e12a4211b14049da":[3,0,10,3,1,35],
-"classzypp_1_1bit_1_1BitField.html#ad29610309310b073e12a4211b14049da":[4,0,7,2,1,35],
-"classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[3,0,10,3,1,10],
-"classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[4,0,7,2,1,10]
+"classzypp_1_1bit_1_1BitField.html#ad29610309310b073e12a4211b14049da":[4,0,7,2,1,35]
 };
