@@ -1,5 +1,9 @@
 var NAVTREEINDEX42 =
 {
+"classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[3,0,10,3,1,10],
+"classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[4,0,7,2,1,10],
+"classzypp_1_1bit_1_1BitField.html#ae1694ae9c2588b3908629d7d7b1a02ed":[3,0,10,3,1,12],
+"classzypp_1_1bit_1_1BitField.html#ae1694ae9c2588b3908629d7d7b1a02ed":[4,0,7,2,1,12],
 "classzypp_1_1bit_1_1BitField.html#ae34a96187910d9b3de34738990849959":[3,0,10,3,1,9],
 "classzypp_1_1bit_1_1BitField.html#ae34a96187910d9b3de34738990849959":[4,0,7,2,1,9],
 "classzypp_1_1bit_1_1BitField.html#af277009722da66b5ea332b55db739e70":[3,0,10,3,1,5],
@@ -245,9 +249,5 @@ var NAVTREEINDEX42 =
 "classzypp_1_1detail_1_1PoolQueryMatcher.html#ac6e8c57c122a63717448ff38bbcb0e53":[4,0,7,5,6,13],
 "classzypp_1_1detail_1_1PoolQueryMatcher.html#ac888eef10e094b4d1ffc70b116bf50c5":[3,0,10,6,6,16],
 "classzypp_1_1detail_1_1PoolQueryMatcher.html#ac888eef10e094b4d1ffc70b116bf50c5":[4,0,7,5,6,16],
-"classzypp_1_1detail_1_1PoolQueryMatcher.html#ae001b9e447efb99c42f7585babdb223b":[3,0,10,6,6,7],
-"classzypp_1_1detail_1_1PoolQueryMatcher.html#ae001b9e447efb99c42f7585babdb223b":[4,0,7,5,6,7],
-"classzypp_1_1detail_1_1PoolQueryMatcher.html#ae1aaaadea137298b9bbb6620f029c2d5":[3,0,10,6,6,10],
-"classzypp_1_1detail_1_1PoolQueryMatcher.html#ae1aaaadea137298b9bbb6620f029c2d5":[4,0,7,5,6,10],
-"classzypp_1_1detail_1_1PoolQueryMatcher.html#aeb24d61aa80d63e20953b8c310f49d65":[3,0,10,6,6,17]
+"classzypp_1_1detail_1_1PoolQueryMatcher.html#ae001b9e447efb99c42f7585babdb223b":[3,0,10,6,6,7]
 };
