@@ -1,5 +1,9 @@
 var NAVTREEINDEX52 =
 {
+"classzypp_1_1media_1_1MediaManager.html#a4ad8d3535fa1f04920fe823e8b04849a":[3,0,10,25,42,31],
+"classzypp_1_1media_1_1MediaManager.html#a4ad8d3535fa1f04920fe823e8b04849a":[4,0,7,22,42,31],
+"classzypp_1_1media_1_1MediaManager.html#a569396e2c9b71a9ee850ccd4e435890d":[3,0,10,25,42,4],
+"classzypp_1_1media_1_1MediaManager.html#a569396e2c9b71a9ee850ccd4e435890d":[4,0,7,22,42,4],
 "classzypp_1_1media_1_1MediaManager.html#a59405f0b6f521c57e37f9553e03b14aa":[3,0,10,25,42,8],
 "classzypp_1_1media_1_1MediaManager.html#a59405f0b6f521c57e37f9553e03b14aa":[4,0,7,22,42,8],
 "classzypp_1_1media_1_1MediaManager.html#a5ac60d2fb06d7eb131ed72a8f78ccb91":[3,0,10,25,42,18],
@@ -245,9 +249,5 @@ var NAVTREEINDEX52 =
 "classzypp_1_1media_1_1MediaNotOpenException.html#a70b9c29895680e92d5bdc9571402ee01":[3,0,10,25,52,3],
 "classzypp_1_1media_1_1MediaNotOpenException.html#a70b9c29895680e92d5bdc9571402ee01":[4,0,7,22,52,3],
 "classzypp_1_1media_1_1MediaNotOpenException.html#ad4832ea0dfd9f2cfc4b8d8fa4de8788c":[3,0,10,25,52,0],
-"classzypp_1_1media_1_1MediaNotOpenException.html#ad4832ea0dfd9f2cfc4b8d8fa4de8788c":[4,0,7,22,52,0],
-"classzypp_1_1media_1_1MediaNotOpenException.html#ae09662c4833daf1f31fbf0da14799d3d":[3,0,10,25,52,2],
-"classzypp_1_1media_1_1MediaNotOpenException.html#ae09662c4833daf1f31fbf0da14799d3d":[4,0,7,22,52,2],
-"classzypp_1_1media_1_1MediaNotSupportedException.html":[3,0,10,25,53],
-"classzypp_1_1media_1_1MediaNotSupportedException.html":[4,0,7,22,53]
+"classzypp_1_1media_1_1MediaNotOpenException.html#ad4832ea0dfd9f2cfc4b8d8fa4de8788c":[4,0,7,22,52,0]
 };
