@@ -1,5 +1,9 @@
 var NAVTREEINDEX53 =
 {
+"classzypp_1_1media_1_1MediaNotOpenException.html#ae09662c4833daf1f31fbf0da14799d3d":[3,0,10,25,52,2],
+"classzypp_1_1media_1_1MediaNotOpenException.html#ae09662c4833daf1f31fbf0da14799d3d":[4,0,7,22,52,2],
+"classzypp_1_1media_1_1MediaNotSupportedException.html":[3,0,10,25,53],
+"classzypp_1_1media_1_1MediaNotSupportedException.html":[4,0,7,22,53],
 "classzypp_1_1media_1_1MediaNotSupportedException.html#a12c157e6d228295f06b0cc2a7ab6bb3b":[3,0,10,25,53,1],
 "classzypp_1_1media_1_1MediaNotSupportedException.html#a12c157e6d228295f06b0cc2a7ab6bb3b":[4,0,7,22,53,1],
 "classzypp_1_1media_1_1MediaNotSupportedException.html#a3093b3b1f15432f8a75be85ed75f05bb":[3,0,10,25,53,0],
@@ -245,9 +249,5 @@ var NAVTREEINDEX53 =
 "classzypp_1_1media_1_1ProxyInfo.html":[4,0,7,22,72],
 "classzypp_1_1media_1_1ProxyInfo.html#a0fbd9637101234cc9a9cb2e81b733d09":[3,0,10,25,72,10],
 "classzypp_1_1media_1_1ProxyInfo.html#a0fbd9637101234cc9a9cb2e81b733d09":[4,0,7,22,72,10],
-"classzypp_1_1media_1_1ProxyInfo.html#a2f3a7b1296f319b7b72cc045b3f341f2":[3,0,10,25,72,13],
-"classzypp_1_1media_1_1ProxyInfo.html#a2f3a7b1296f319b7b72cc045b3f341f2":[4,0,7,22,72,13],
-"classzypp_1_1media_1_1ProxyInfo.html#a4eecaded921004f361379cb83e767bff":[3,0,10,25,72,9],
-"classzypp_1_1media_1_1ProxyInfo.html#a4eecaded921004f361379cb83e767bff":[4,0,7,22,72,9],
-"classzypp_1_1media_1_1ProxyInfo.html#a528fd993cd7de980a8220a04f9f72b60":[3,0,10,25,72,3]
+"classzypp_1_1media_1_1ProxyInfo.html#a2f3a7b1296f319b7b72cc045b3f341f2":[3,0,10,25,72,13]
 };
