@@ -1,5 +1,7 @@
 var NAVTREEINDEX54 =
 {
+"classzypp_1_1media_1_1ProxyInfo.html#a2f3a7b1296f319b7b72cc045b3f341f2":[4,0,7,22,72,13],
+"classzypp_1_1media_1_1ProxyInfo.html#a4eecaded921004f361379cb83e767bff":[3,0,10,25,72,9],
 "classzypp_1_1media_1_1ProxyInfo.html#a4eecaded921004f361379cb83e767bff":[4,0,7,22,72,9],
 "classzypp_1_1media_1_1ProxyInfo.html#a528fd993cd7de980a8220a04f9f72b60":[3,0,10,25,72,3],
 "classzypp_1_1media_1_1ProxyInfo.html#a528fd993cd7de980a8220a04f9f72b60":[4,0,7,22,72,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX54 =
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac398cad18a37074b89cd893db9a56a4d":[4,0,7,22,77,0,27],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac509a54a6841056310c9a1cd9f40140c":[3,0,10,25,77,0,12],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac509a54a6841056310c9a1cd9f40140c":[4,0,7,22,77,0,12],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac5721cc33169fbed0d12128adc3f50e2":[3,0,10,25,77,0,4],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac5721cc33169fbed0d12128adc3f50e2":[4,0,7,22,77,0,4],
-"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac96166b8c1401e8895b0e901d0e13484":[3,0,10,25,77,0,18]
+"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac5721cc33169fbed0d12128adc3f50e2":[3,0,10,25,77,0,4]
 };
