@@ -1,5 +1,9 @@
 var NAVTREEINDEX55 =
 {
+"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac5721cc33169fbed0d12128adc3f50e2":[4,0,7,22,77,0,4],
+"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac96166b8c1401e8895b0e901d0e13484":[3,0,10,25,77,0,18],
+"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ac96166b8c1401e8895b0e901d0e13484":[4,0,7,22,77,0,18],
+"classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ace59493de0b2b0337690d85d01584b66":[3,0,10,25,77,0,25],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#ace59493de0b2b0337690d85d01584b66":[4,0,7,22,77,0,25],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#acfceb085eb9d6e8a44dfc1276c9934af":[3,0,10,25,77,0,5],
 "classzypp_1_1media_1_1TransferSettings_1_1Impl.html#acfceb085eb9d6e8a44dfc1276c9934af":[4,0,7,22,77,0,5],
@@ -245,9 +249,5 @@ var NAVTREEINDEX55 =
 "classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#a6ef1d99b0b3ff66fa449af59fb0b7a9b":[4,0,7,24,0,0,2],
 "classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#a766d1ba1466c15aa93589625f4ff49e0":[3,0,10,27,0,0,5],
 "classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#a766d1ba1466c15aa93589625f4ff49e0":[4,0,7,24,0,0,5],
-"classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#ac62d817014f587bb72c281172038d13b":[3,0,10,27,0,0,3],
-"classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#ac62d817014f587bb72c281172038d13b":[4,0,7,24,0,0,3],
-"classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#acd5aae1c67d848bf5af7351f0115a07d":[3,0,10,27,0,0,4],
-"classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#acd5aae1c67d848bf5af7351f0115a07d":[4,0,7,24,0,0,4],
-"classzypp_1_1parser_1_1HistoryLogReader.html":[3,0,10,28,2]
+"classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#ac62d817014f587bb72c281172038d13b":[3,0,10,27,0,0,3]
 };
