@@ -1,5 +1,9 @@
 var NAVTREEINDEX56 =
 {
+"classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#ac62d817014f587bb72c281172038d13b":[4,0,7,24,0,0,3],
+"classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#acd5aae1c67d848bf5af7351f0115a07d":[3,0,10,27,0,0,4],
+"classzypp_1_1packagedelta_1_1DeltaRpm_1_1BaseVersion.html#acd5aae1c67d848bf5af7351f0115a07d":[4,0,7,24,0,0,4],
+"classzypp_1_1parser_1_1HistoryLogReader.html":[3,0,10,28,2],
 "classzypp_1_1parser_1_1HistoryLogReader.html":[4,0,7,25,2],
 "classzypp_1_1parser_1_1HistoryLogReader.html#a0c801c3a20163126e56700165dfe43f6":[3,0,10,28,2,12],
 "classzypp_1_1parser_1_1HistoryLogReader.html#a0c801c3a20163126e56700165dfe43f6":[4,0,7,25,2,12],
@@ -245,9 +249,5 @@ var NAVTREEINDEX56 =
 "classzypp_1_1parser_1_1RepoindexFileReader.html#acc350e17a5b44924343731d9ab6ad9c2":[3,0,10,28,11,5],
 "classzypp_1_1parser_1_1RepoindexFileReader.html#acc350e17a5b44924343731d9ab6ad9c2":[4,0,7,25,11,5],
 "classzypp_1_1parser_1_1RepoindexFileReader.html#ace1b269257716e28a72e76cc16a1901b":[3,0,10,28,11,4],
-"classzypp_1_1parser_1_1RepoindexFileReader.html#ace1b269257716e28a72e76cc16a1901b":[4,0,7,25,11,4],
-"classzypp_1_1parser_1_1RepoindexFileReader_1_1Impl.html":[3,0,10,28,11,0],
-"classzypp_1_1parser_1_1RepoindexFileReader_1_1Impl.html":[4,0,7,25,11,0],
-"classzypp_1_1parser_1_1RepoindexFileReader_1_1Impl.html#a4a3fb8d176773b5f2cf0df9519fc4c23":[3,0,10,28,11,0,3],
-"classzypp_1_1parser_1_1RepoindexFileReader_1_1Impl.html#a4a3fb8d176773b5f2cf0df9519fc4c23":[4,0,7,25,11,0,3]
+"classzypp_1_1parser_1_1RepoindexFileReader.html#ace1b269257716e28a72e76cc16a1901b":[4,0,7,25,11,4]
 };
