@@ -1,5 +1,9 @@
 var NAVTREEINDEX59 =
 {
+"classzypp_1_1repo_1_1RepoInvalidAliasException.html#aa01de78e542fe36d6db227c2b074a725":[4,0,7,27,12,1],
+"classzypp_1_1repo_1_1RepoInvalidAliasException.html#aa15f2d41ea404267aab5adfe99d2c107":[3,0,10,32,13,2],
+"classzypp_1_1repo_1_1RepoInvalidAliasException.html#aa15f2d41ea404267aab5adfe99d2c107":[4,0,7,27,12,2],
+"classzypp_1_1repo_1_1RepoMediaAccess.html":[3,0,10,32,14],
 "classzypp_1_1repo_1_1RepoMediaAccess.html":[4,0,7,27,13],
 "classzypp_1_1repo_1_1RepoMediaAccess.html#a0c2e601bbfc469c35265848c1a9850cd":[3,0,10,32,14,5],
 "classzypp_1_1repo_1_1RepoMediaAccess.html#a0c2e601bbfc469c35265848c1a9850cd":[4,0,7,27,13,5],
@@ -245,9 +249,5 @@ var NAVTREEINDEX59 =
 "classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a3d52388115c2d08f18bfae994667302d":[4,0,7,27,31,0],
 "classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a60d1a8ab861ba576e62519cc8d098566":[3,0,10,32,32,2],
 "classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a60d1a8ab861ba576e62519cc8d098566":[4,0,7,27,31,2],
-"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#abf41bbefec013fa271eab313471fee15":[3,0,10,32,32,1],
-"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#abf41bbefec013fa271eab313471fee15":[4,0,7,27,31,1],
-"classzypp_1_1repo_1_1ServiceNoAliasException.html":[3,0,10,32,33],
-"classzypp_1_1repo_1_1ServiceNoAliasException.html":[4,0,7,27,32],
-"classzypp_1_1repo_1_1ServiceNoAliasException.html#a391660b78fcdb517357e6d112fa743b7":[3,0,10,32,33,3]
+"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#abf41bbefec013fa271eab313471fee15":[3,0,10,32,32,1]
 };
