@@ -1,5 +1,9 @@
 var NAVTREEINDEX60 =
 {
+"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#abf41bbefec013fa271eab313471fee15":[4,0,7,27,31,1],
+"classzypp_1_1repo_1_1ServiceNoAliasException.html":[3,0,10,32,33],
+"classzypp_1_1repo_1_1ServiceNoAliasException.html":[4,0,7,27,32],
+"classzypp_1_1repo_1_1ServiceNoAliasException.html#a391660b78fcdb517357e6d112fa743b7":[3,0,10,32,33,3],
 "classzypp_1_1repo_1_1ServiceNoAliasException.html#a391660b78fcdb517357e6d112fa743b7":[4,0,7,27,32,3],
 "classzypp_1_1repo_1_1ServiceNoAliasException.html#a601989d893f2947462e9c4a778af7bd4":[3,0,10,32,33,2],
 "classzypp_1_1repo_1_1ServiceNoAliasException.html#a601989d893f2947462e9c4a778af7bd4":[4,0,7,27,32,2],
@@ -245,9 +249,5 @@ var NAVTREEINDEX60 =
 "classzypp_1_1sat_1_1LookupAttr.html#af7f47657ad76dbda9b8d895365d33569":[3,0,10,37,7,33],
 "classzypp_1_1sat_1_1LookupAttr.html#af7f47657ad76dbda9b8d895365d33569":[4,0,7,31,8,33],
 "classzypp_1_1sat_1_1LookupAttr.html#afaee6d0bea6e3fcbe9983965e8cbe69c":[3,0,10,37,7,11],
-"classzypp_1_1sat_1_1LookupAttr.html#afaee6d0bea6e3fcbe9983965e8cbe69c":[4,0,7,31,8,11],
-"classzypp_1_1sat_1_1LookupAttr_1_1Impl.html":[3,0,10,37,7,0],
-"classzypp_1_1sat_1_1LookupAttr_1_1Impl.html":[4,0,7,31,8,0],
-"classzypp_1_1sat_1_1LookupAttr_1_1Impl.html#a0d1b97df9053251491fe33b32aff520d":[3,0,10,37,7,0,22],
-"classzypp_1_1sat_1_1LookupAttr_1_1Impl.html#a0d1b97df9053251491fe33b32aff520d":[4,0,7,31,8,0,22]
+"classzypp_1_1sat_1_1LookupAttr.html#afaee6d0bea6e3fcbe9983965e8cbe69c":[4,0,7,31,8,11]
 };
