@@ -1,5 +1,7 @@
 var NAVTREEINDEX63 =
 {
+"classzypp_1_1sat_1_1SolvAttr.html#a371dce4d2a124eabec2959fc1fbb96f7":[3,0,10,37,15,106],
+"classzypp_1_1sat_1_1SolvAttr.html#a371dce4d2a124eabec2959fc1fbb96f7":[4,0,7,31,16,106],
 "classzypp_1_1sat_1_1SolvAttr.html#a375883aea755992998e33e2b4369e829":[3,0,10,37,15,10],
 "classzypp_1_1sat_1_1SolvAttr.html#a375883aea755992998e33e2b4369e829":[4,0,7,31,16,10],
 "classzypp_1_1sat_1_1SolvAttr.html#a3892be95ee89ef94912bc8783b950911":[3,0,10,37,15,110],
@@ -247,7 +249,5 @@ var NAVTREEINDEX63 =
 "classzypp_1_1sat_1_1Solvable.html#a0ac33b9faf69b7b78d3e34998e5b509a":[3,0,10,37,12,88],
 "classzypp_1_1sat_1_1Solvable.html#a0ac33b9faf69b7b78d3e34998e5b509a":[4,0,7,31,13,88],
 "classzypp_1_1sat_1_1Solvable.html#a0b4efb77a00cc0ff20638833bb19c5a4":[3,0,10,37,12,7],
-"classzypp_1_1sat_1_1Solvable.html#a0b4efb77a00cc0ff20638833bb19c5a4":[4,0,7,31,13,7],
-"classzypp_1_1sat_1_1Solvable.html#a0bb9ebf1b941548776d64c6f4fc03fc1":[3,0,10,37,117],
-"classzypp_1_1sat_1_1Solvable.html#a0bb9ebf1b941548776d64c6f4fc03fc1":[3,0,10,37,12,95]
+"classzypp_1_1sat_1_1Solvable.html#a0b4efb77a00cc0ff20638833bb19c5a4":[4,0,7,31,13,7]
 };
