@@ -1,5 +1,9 @@
 var NAVTREEINDEX73 =
 {
+"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#aa7188af8694ada671c75d44bab102115":[3,0,10,43,0,12,1,0,9],
+"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#aa7188af8694ada671c75d44bab102115":[4,0,7,36,0,11,1,0,9],
+"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#ab08c57b6397fae8261b31a68f8de25e9":[3,0,10,43,0,12,1,0,14],
+"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#ab08c57b6397fae8261b31a68f8de25e9":[4,0,7,36,0,11,1,0,14],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#ab4cc0def4e995754f7cfd74b20abf04e":[3,0,10,43,0,12,1,0,12],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#ab4cc0def4e995754f7cfd74b20abf04e":[4,0,7,36,0,11,1,0,12],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#ab555481b15494ccd801c168e517cce3f":[3,0,10,43,0,12,1,0,11],
@@ -245,9 +249,5 @@ var NAVTREEINDEX73 =
 "classzypp_1_1ui_1_1StatusBackup.html#a076a486f83032174f36965ba8158b823":[3,0,10,45,4,12],
 "classzypp_1_1ui_1_1StatusBackup.html#a076a486f83032174f36965ba8158b823":[4,0,7,37,4,12],
 "classzypp_1_1ui_1_1StatusBackup.html#a11d1f0fbccadfac37a2271b1e654a86a":[3,0,10,45,4,11],
-"classzypp_1_1ui_1_1StatusBackup.html#a11d1f0fbccadfac37a2271b1e654a86a":[4,0,7,37,4,11],
-"classzypp_1_1ui_1_1StatusBackup.html#a2af33786e2f6f6136f12c8e6b551fbba":[3,0,10,45,4,1],
-"classzypp_1_1ui_1_1StatusBackup.html#a2af33786e2f6f6136f12c8e6b551fbba":[4,0,7,37,4,1],
-"classzypp_1_1ui_1_1StatusBackup.html#a2ec883c7392063b86d8a696c38e4ed7d":[3,0,10,45,4,16],
-"classzypp_1_1ui_1_1StatusBackup.html#a2ec883c7392063b86d8a696c38e4ed7d":[4,0,7,37,4,16]
+"classzypp_1_1ui_1_1StatusBackup.html#a11d1f0fbccadfac37a2271b1e654a86a":[4,0,7,37,4,11]
 };
