@@ -1,5 +1,9 @@
 var NAVTREEINDEX74 =
 {
+"classzypp_1_1ui_1_1StatusBackup.html#a2af33786e2f6f6136f12c8e6b551fbba":[3,0,10,45,4,1],
+"classzypp_1_1ui_1_1StatusBackup.html#a2af33786e2f6f6136f12c8e6b551fbba":[4,0,7,37,4,1],
+"classzypp_1_1ui_1_1StatusBackup.html#a2ec883c7392063b86d8a696c38e4ed7d":[3,0,10,45,4,16],
+"classzypp_1_1ui_1_1StatusBackup.html#a2ec883c7392063b86d8a696c38e4ed7d":[4,0,7,37,4,16],
 "classzypp_1_1ui_1_1StatusBackup.html#a386181bf48904272e42558e76a2dba99":[3,0,10,45,4,7],
 "classzypp_1_1ui_1_1StatusBackup.html#a386181bf48904272e42558e76a2dba99":[4,0,7,37,4,7],
 "classzypp_1_1ui_1_1StatusBackup.html#a3ac2bf814827b6827ec503bf1b0b21f6":[3,0,10,45,4,14],
@@ -245,9 +249,5 @@ var NAVTREEINDEX74 =
 "classzypp_1_1url_1_1UrlNotSupportedException.html#acd53e15fafb48710adc06c9f54bc4185":[3,0,10,46,7,2],
 "classzypp_1_1url_1_1UrlNotSupportedException.html#acd53e15fafb48710adc06c9f54bc4185":[4,0,7,38,7,2],
 "classzypp_1_1url_1_1UrlParsingException.html":[3,0,10,46,8],
-"classzypp_1_1url_1_1UrlParsingException.html":[4,0,7,38,8],
-"classzypp_1_1url_1_1UrlParsingException.html#a761bd7633a11bc9b4a399a02148be77d":[3,0,10,46,8,2],
-"classzypp_1_1url_1_1UrlParsingException.html#a761bd7633a11bc9b4a399a02148be77d":[4,0,7,38,8,2],
-"classzypp_1_1url_1_1UrlParsingException.html#a773a4a6088819e4cc3f42e23306166d0":[3,0,10,46,8,1],
-"classzypp_1_1url_1_1UrlParsingException.html#a773a4a6088819e4cc3f42e23306166d0":[4,0,7,38,8,1]
+"classzypp_1_1url_1_1UrlParsingException.html":[4,0,7,38,8]
 };
