@@ -1,5 +1,9 @@
 var NAVTREEINDEX85 =
 {
+"classzyppng_1_1ProgressObserverPrivate.html#a71b148b6f5ba37bcd2ea3005de65f715":[4,0,9,87,14],
+"classzyppng_1_1ProgressObserverPrivate.html#a7b5b108d8342ea902c9746ca6630ffa6":[3,0,13,125,25],
+"classzyppng_1_1ProgressObserverPrivate.html#a7b5b108d8342ea902c9746ca6630ffa6":[4,0,9,87,25],
+"classzyppng_1_1ProgressObserverPrivate.html#a93fe8a114d0769cd08b295bb8f6f3029":[3,0,13,125,21],
 "classzyppng_1_1ProgressObserverPrivate.html#a93fe8a114d0769cd08b295bb8f6f3029":[4,0,9,87,21],
 "classzyppng_1_1ProgressObserverPrivate.html#ab1320295dc134f9291ac896f4083b163":[3,0,13,125,9],
 "classzyppng_1_1ProgressObserverPrivate.html#ab1320295dc134f9291ac896f4083b163":[4,0,9,87,9],
@@ -245,9 +249,5 @@ var NAVTREEINDEX85 =
 "classzyppng_1_1ProvideFileSpec_1_1Impl.html#a136243cf687237d4c45968634582870c":[4,0,9,90,0,8],
 "classzyppng_1_1ProvideFileSpec_1_1Impl.html#a1d49e3502cac5f150f609274918eba16":[3,0,13,128,0,6],
 "classzyppng_1_1ProvideFileSpec_1_1Impl.html#a1d49e3502cac5f150f609274918eba16":[4,0,9,90,0,6],
-"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a3d5abf3be46e7f2d21bf9eadfed9c7d5":[3,0,13,128,0,10],
-"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a3d5abf3be46e7f2d21bf9eadfed9c7d5":[4,0,9,90,0,10],
-"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a4cac11893a79f8f5f99f167eaa67937a":[3,0,13,128,0,11],
-"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a4cac11893a79f8f5f99f167eaa67937a":[4,0,9,90,0,11],
-"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a678ce35ad39a4a892ade6410e7ff7b21":[3,0,13,128,0,13]
+"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a3d5abf3be46e7f2d21bf9eadfed9c7d5":[3,0,13,128,0,10]
 };
