@@ -1,5 +1,9 @@
 var NAVTREEINDEX89 =
 {
+"classzyppng_1_1RepoManager.html#ad909c8b8c2920154eaec98c3afe4a2f9":[4,0,9,110,58],
+"classzyppng_1_1RepoManager.html#adedc569d9edf0ca18d7af56b28673a0a":[3,0,13,148,24],
+"classzyppng_1_1RepoManager.html#adedc569d9edf0ca18d7af56b28673a0a":[4,0,9,110,24],
+"classzyppng_1_1RepoManager.html#ae0942e4a131017a915637c8d31931682":[3,0,13,148,76],
 "classzyppng_1_1RepoManager.html#ae0942e4a131017a915637c8d31931682":[4,0,9,110,76],
 "classzyppng_1_1RepoManager.html#ae3580629e7becc08efd550ed3831b25c":[3,0,13,148,22],
 "classzyppng_1_1RepoManager.html#ae3580629e7becc08efd550ed3831b25c":[4,0,9,110,22],
@@ -245,9 +249,5 @@ var NAVTREEINDEX89 =
 "classzyppng_1_1SocketNotifier.html#ae4589d6fde1cd6c6f044f88d1e0fb93d":[4,0,9,122,5],
 "classzyppng_1_1SocketNotifier.html#afbff7b185af4a46756a4228ab74cfa47":[3,0,13,160,7],
 "classzyppng_1_1SocketNotifier.html#afbff7b185af4a46756a4228ab74cfa47":[4,0,9,122,7],
-"classzyppng_1_1SocketNotifierPrivate.html":[3,0,13,161],
-"classzyppng_1_1SocketNotifierPrivate.html":[4,0,9,123],
-"classzyppng_1_1SocketNotifierPrivate.html#a0d0a22edf7348cf2be5ee081f5db1d66":[3,0,13,161,0],
-"classzyppng_1_1SocketNotifierPrivate.html#a0d0a22edf7348cf2be5ee081f5db1d66":[4,0,9,123,0],
-"classzyppng_1_1SocketNotifierPrivate.html#a0f665de0fbd8f83c8ef02d30f2f43942":[3,0,13,161,1]
+"classzyppng_1_1SocketNotifierPrivate.html":[3,0,13,161]
 };
